path = r'C:\Users\mjaquier\PycharmProjects\aithermal\tests'

import aihelper.aifile as afile

def main():
    allthedata = afile.topic_directories(path)
    print('h')



if __name__ == '__main__':
    main()